@@ -4,7 +4,7 @@ use warnings;
 
 use Carp qw(croak);
 
-our $VERSION = '0.07_02';
+our $VERSION = '0.07_03';
 
 require XSLoader;
 XSLoader::load('RPi::DHT11', $VERSION);
@@ -17,7 +17,7 @@ sub new {
     my $self = bless {}, $class;
     $self->_pin($pin);
 
-    sanity();
+    setup();
 
     return $self;
 }
@@ -61,7 +61,7 @@ Raspberry Pi
 
     use RPi::DHT11;
 
-    my $pin = 26;
+    my $pin = 18;
 
     my $env = RPi::DHT11->new($pin);
 
@@ -71,10 +71,15 @@ Raspberry Pi
 =head1 DESCRIPTION
 
 This module is an interface to the DHT11 temperature/humidity sensor when
-connected to a Raspberry Pi's GPIO pins.
+connected to a Raspberry Pi's GPIO pins. We use the BCM GPIO pin numbering
+scheme.
 
-Due to the near-realtime access requirements of reading the input pin of the
-sensor, the core of this module is written in XS (C).
+If you create an L<RPi::WiringPi> object before creating an object in this
+class, you can set up the C<RPi::WiringPi> object with whichever pin
+numbering scheme you choose, and this module will follow suit. Eg: if you
+set C<RPi::WiringPi> to C<wpi> pin scheme, we'll use it here as well. Note,
+though, that you MUST create the C<RPi::WiringPi> object before you create one
+of this class!
 
 This module requires the L<wiringPi|http://wiringpi.com/> library to be
 installed, and uses WiringPi's GPIO pin numbering scheme (see C<gpio readall>
@@ -88,25 +93,25 @@ Parameters:
 
     $pin
 
-Mandatory. Pin number for the DHT11 sensor's DATA pin (values are 0-40).
+Mandatory. BCM GPIO pin number for the DHT11 sensor's DATA pin..
 
-=head2 temp($f)
+=head2 temp('f')
 
-Fetches the current temperature (in Celcius).
+Fetches the current temperature.
 
-Returns an integer of the temperature, in celcius by default.
+Returns an integer of the temperature, in Celcius by default.
 
 Parameters:
 
-    $f
+    'f'
 
-Send in the string char C<'f'> to receive the temp in Farenheit.
+Optional: Send in the string char C<'f'> to receive the temp in Farenheit.
 
 =head2 humidity
 
 Fetches the current humidity.
 
-Returns the humidity as either an integer of the current humidity level.
+Returns the current humidity percentage as an integer.
 
 =head2 cleanup
 
@@ -130,6 +135,8 @@ return default (ie. non-live) data when in this mode.
 =head1 SEE ALSO
 
 - L<wiringPi|http://wiringpi.com/>
+- L<WiringPi::API>
+- L <RPi::WiringPi>
 
 =head1 AUTHOR
 
